# Ibis Birdbrain

The portable Python ML-powered data bot for your data project. Currently under construction by slow humans and highly experimental.

Powered by [Ibis](https://ibis-project.org), your data platform, [Marvin](https://github.com/prefectHQ/marvin), and your ML platform.
